@@ -2,7 +2,7 @@ package Devel::Cover::Report::Coveralls;
 use strict;
 use warnings;
 use 5.008005;
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 our $CONFIG_FILE = '.coveralls.yml';
 our $API_ENDPOINT = 'https://coveralls.io/api/v1/jobs';
@@ -61,6 +61,10 @@ sub get_git_info {
     $branch =~ s/^\* //;
     $git->{branch} = $branch;
 
+    if ($ENV{GITHUB_REF} && $ENV{GITHUB_REF} =~ m![^/]+/[^/]+/(.+)$!) {
+        $git->{branch} = $1;
+    }
+
     return $git;
 }
 
